package com.sun.rmi.rmid;

import java.util.Enumeration;
import java.util.Vector;
import java.io.Serializable;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.security.PermissionCollection;
import java.io.FilePermission;
import java.security.Permission;

public final class ExecPermission extends Permission
{
    private static final long serialVersionUID = -6208470287358147919L;
    private transient FilePermission fp;
    
    public ExecPermission(String name) {
        super(name);
        this.init(name);
    }
    
    public ExecPermission(String s, String s2) {
        this(s);
    }
    
    @Override
    public boolean implies(Permission permission) {
        return permission instanceof ExecPermission && this.fp.implies(((ExecPermission)permission).fp);
    }
    
    @Override
    public boolean equals(Object o) {
        return o == this || (o instanceof ExecPermission && this.fp.equals(((ExecPermission)o).fp));
    }
    
    @Override
    public int hashCode() {
        return this.fp.hashCode();
    }
    
    @Override
    public String getActions() {
        return "";
    }
    
    @Override
    public PermissionCollection newPermissionCollection() {
        return new ExecPermission.ExecPermissionCollection();
    }
    
    private synchronized void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
        objectInputStream.defaultReadObject();
        this.init(this.getName());
    }
    
    private void init(String path) {
        this.fp = new FilePermission(path, "execute");
    }
    
    private static class ExecPermissionCollection extends PermissionCollection implements Serializable
    {
        private Vector<Permission> permissions;
        private static final long serialVersionUID = -3352558508888368273L;
        
        public ExecPermissionCollection() {
            this.permissions = new Vector();
        }
        
        @Override
        public void add(Permission permission) {
            if (!(permission instanceof ExecPermission)) {
                throw new IllegalArgumentException("invalid permission: " + permission);
            }
            if (this.isReadOnly()) {
                throw new SecurityException("attempt to add a Permission to a readonly PermissionCollection");
            }
            this.permissions.addElement(permission);
            return;
        }
        
        @Override
        public boolean implies(Permission permission) {
            if (!(permission instanceof ExecPermission)) {
                return false;
            }
            Enumeration<Permission> elements = this.permissions.elements();
            while (elements.hasMoreElements()) {
                if (((ExecPermission)elements.nextElement()).implies(permission)) {
                    return true;
                }
                continue;
            }
            return false;
        }
        
        @Override
        public Enumeration<Permission> elements() {
            return this.permissions.elements();
        }
    }
}
